addDatabase: Add a Database to a PAMrSettings Object

Description Usage Arguments Value Author(s) Examples

View source: R/addDatabase.R

Description

Adds a new function to the "function" slot in a PAMrSettings object.

Usage

1

Arguments

prs

a PAMrSettings object to add a database to

db

a database to add

Value

the same PAMrSettings object as prs, with the database db added to the "db" slot

Author(s)

Taiki Sakai taiki.sakai@noaa.gov

Examples

1
2
3
4
5
# not recommended to create a prs like this, for example only
prs <- new('PAMrSettings')
db <- system.file('extdata', 'Example.sqlite3', package='PAMr')
prs <- addDatabase(prs, db)
prs

TaikiSan21/PAMr documentation built on Nov. 15, 2020, 9:46 p.m.