Description Usage Arguments Value Author(s)
View source: R/processPgDetections.R
Loads and processes acoustic detection data that has been
run through Pamguard. Uses the binary files and database(s) contained
in prs, and will either group your data into events by the
grouping present in the 'OfflineEvents' or 'Detection Group Localiser'
tables (mode = 'db') or by the grouping specified by start/end
times in the supplied grouping (mode = 'time'). Will apply
all processing functions in prs to the appropriate modules
1 2 3 4 5 6 7 8 |
prs |
a PAMrSettings object containing the databases,
binaries, and functions to use for processing data. See
|
mode |
selector for how to organize your data in to events. |
id |
an event name or id for this study, will default to today's date if not supplied (recommended to supply your own informative id) |
grouping |
For For
|
format |
the date format for the |
... |
additional arguments to pass onto to different methods |
an AcousticStudy object with one AcousticEvent
for each event in the events slot, and the PAMrSettings object
used stored in the prs slot.
Taiki Sakai taiki.sakai@noaa.gov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.