roccaWhistleCalcs: Calculate a Set of Measurements for Whistles

Description Usage Arguments Value Author(s)

View source: R/roccaWhistleCalcs.R

Description

Calculate a set of measurements from a whistle contour. All calculations following ROCCA method from Julie and Michael Oswald, as implemented in Pamguard.

Usage

1

Arguments

data

a list that must have freq the whistle contour stored as a vector of FFT bin frequencies in hertz, and time the time in seconds at each bin.

Value

A list with 50 calculated rocca parameters, each item in the list will only have 1 entry so that this can easily be converted to a data frame.

Author(s)

Taiki Sakai taiki.sakai@noaa.gov


TaikiSan21/PAMr documentation built on Nov. 15, 2020, 9:46 p.m.