updateFiles: Update Location of Binary and Databases Files

Description Usage Arguments Value Author(s)

View source: R/updateFiles.R

Description

Updates the stored locations of binary and database files in the files slots of all AcousticStudy and AcousticEvent objects. Typically used after changing computers, or if original data was on an external hard drive. If any missing files are not able to be located, they will be kept in the files slot so that this function can be run again

Usage

1
updateFiles(x, bin = NULL, db = NULL, quiet = FALSE)

Arguments

x

an AcousticStudy or AcousticEvent object

bin

folder containing updated binary file locations. If NULL (default), user will be prompted to select a folder

db

folder containing updated database file locations. If NULL (default), user will be prompted to select a folder

quiet

logical flag to print messages about success of replacement

Value

the same AcousticStudy and AcousticEvent object as x with updated file locations

Author(s)

Taiki Sakai taiki.sakai@noaa.gov


TaikiSan21/PAMr documentation built on Nov. 15, 2020, 9:46 p.m.