writeEventClips: Create Wav Clips of Events

Description Usage Arguments Value Author(s)

View source: R/writeEventClips.R

Description

Creates an audio clip containing sounds from an event

Usage

1
2
3
4
5
6
7
writeEventClips(
  event,
  wavFolder = NULL,
  buffer = 0.1,
  format = c("pamguard", "soundtrap"),
  log = NULL
)

Arguments

event

AcousticEvent or AcousticStudy object containing events to make wav clips for

wavFolder

the folder where the wav files are located

buffer

amount around each event to also include in the clip, in seconds

format

either 'pamguard' or 'soundtrap' specifying how the original audio files were created. The names of these files must not have been changed, the original formatting is used to parse out the start times of the audio files

log

optional location of SoundTrap XML log files, only relevant for format='soundtrap'

Value

A vector of file names for the wav clips that were successfully created, any that were not able to be written will be NA

Author(s)

Taiki Sakai taiki.sakai@noaa.gov


TaikiSan21/PAMr documentation built on Nov. 15, 2020, 9:46 p.m.