Description Usage Arguments Value Author(s)
Extracts all variables from a netcdf file matching Longitude, Latitude, and UTC coordinates in given dataframe
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 | ## S4 method for signature 'AcousticEvent'
matchEnvData(
data,
nc = NULL,
var = NULL,
buffer = c(0, 0, 0),
FUN = c(mean, median, sd),
fileName = NULL,
...
)
## S4 method for signature 'AcousticStudy'
matchEnvData(
data,
nc = NULL,
var = NULL,
buffer = c(0, 0, 0),
FUN = c(mean, median, sd),
fileName = NULL,
...
)
|
data |
an AcousticStudy or AcousticEvent object that must have GPS data added to it using the addGps functions |
nc |
name of a netcdf file, ERDDAP dataset id, or an edinfo object |
var |
(optional) vector of variable names |
buffer |
vector of Longitude, Latitude, and Time (seconds) to buffer around each datapoint. All values within the buffer will be used to report the mean, median, and standard deviation |
FUN |
a vector or list of functions to apply to the data. Default is to apply mean, median, and standard deviation calculations |
fileName |
(optional) file name to save downloaded nc file to. If not provided,
then no nc files will be stored, instead small temporary files will be downloaded
and then deleted. This can be much faster, but means that the data will need to be
downloaded again in the future. If |
... |
other parameters to pass to ncToData |
original data object with environmental data added to the ancillary slot
of each event. Complete data will be stored in ancillary(data)$environmental,
and the mean of each downloaded variable will be stored in ancillary(data)$measures
so that it can be exported for modeling
Taiki Sakai taiki.sakai@noaa.gov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.