Description Usage Arguments Value Author(s)
View source: R/roccaWhistleCalcs.R
Calculate a set of measurements from a whistle contour. All calculations following ROCCA method from Julie and Michael Oswald, as implemented in Pamguard.
1 |
data |
a list that must have |
A list with 50 calculated rocca parameters, each item in the list will only have 1 entry so that this can easily be converted to a data frame.
Taiki Sakai taiki.sakai@noaa.gov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.