Description Usage Arguments Value Author(s)
Updates the stored locations of binary and database files in
the files slots of all AcousticStudy and
AcousticEvent objects. Typically used after changing
computers, or if original data was on an external hard drive. If any
missing files are not able to be located, they will be kept in the files
slot so that this function can be run again
1 | updateFiles(x, bin = NULL, db = NULL, quiet = FALSE)
|
x |
an AcousticStudy or AcousticEvent object |
bin |
folder containing updated binary file locations. If
|
db |
folder containing updated database file locations. If
|
quiet |
logical flag to print messages about success of replacement |
the same AcousticStudy and
AcousticEvent object as x with
updated file locations
Taiki Sakai taiki.sakai@noaa.gov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.