Description Usage Arguments Value Author(s)
View source: R/writeEventClips.R
Creates an audio clip containing sounds from an event
1 2 3 4 5 6 7 |
event |
AcousticEvent or AcousticStudy object containing events to make wav clips for |
wavFolder |
the folder where the wav files are located |
buffer |
amount around each event to also include in the clip, in seconds |
format |
either |
log |
optional location of SoundTrap XML log files, only relevant for
|
A vector of file names for the wav clips that were successfully
created, any that were not able to be written will be NA
Taiki Sakai taiki.sakai@noaa.gov
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.